netapp_ontap.models.svm_snapmirror API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.svm_snapmirror`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SvmSnapmirrorSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SvmSnapmirror object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `is_protected GET`

    Specifies whether the SVM is a SnapMirror source SVM, using SnapMirror to protect its data.

  `protected_volumes_count GET`

    Specifies the number of SVM DR protected volumes in the SVM.